
;+
;PROCEDURE:	get_geo_mag
;PURPOSE:	Gets key parameter data from the Geotail magnetic field
;		experiment
;INPUT:	
;	none but will call "timespan" and ask for input if
;	time range not already set
;KEYWORDS:
;	none
;LEGENDS:
;	ge_pos: position of S/C in Re
;	B: 3 componenets of B in gammas
;	ge_B_mag:	 Magnitude of B
;	ge_B_lamda: Angle between B vector and y-z plane
;	ge_B_phi:   Angle between B vector in y-z plane and the z axis
;	ge_B_th: Davin's theta angle (see cart_to_sphere.pro)
;	ge_B_ph: Davin's phi angle

;
;CREATED BY:	Tai Phan (modified from Davin Larson's get_mfi)
;LAST MODIFICATION:	@(#)get_mfi.pro	1.8 95/09/07 (Mcfadden 95/1/8)
;-


pro get_geo_mag       
@wind_com.pro
init_wind_lib
fname = data_directory+'ge_k0_mgf_files'
get_file_names,filenames,TIME_RANGE=range,MASTERFILE=fname
ndays = n_elements(filenames)



if ndays eq 0 then begin
   print,"No WIND data available from ",time_to_str(range(0)), ' to  ',time_to_str(range(1))
   return
endif

for d=0,ndays-1 do begin
   print,'Loading file: ',filenames(d),'...'
   loadcdf,filenames(d),'Time_PB5',pb5  &   t = pb5_to_time(pb5)
;	print_cdf_info,filenames(d)


   loadcdf,filenames(d),'IB',ib
   loadcdf,filenames(d),'IB_vector',ib_vector
;   loadcdf,filenames(d),'IS_vector',is_vector
   loadcdf,filenames(d),'POS',pos


   if d eq 0 then begin
        t_tot  = t
        pos_tot = pos/6370.
        bmag_tot = ib
        b_tot = ib_vector
   endif else begin
        t_tot  = [t_tot,t]
	pos_tot= [pos_tot, pos/6370.]
	bmag_tot= [bmag_tot,ib]
	b_tot= [b_tot, ib_vector]
   endelse
endfor

bmag_tot=bmag_tot/10.	; convert nT to gammas
b_tot=b_tot/10.	; convert nT to gammas

cart_to_sphere2,b_tot(*,0),b_tot(*,1),b_tot(*,2),$
bmag,lamda,phi
cart_to_sphere,b_tot(*,0),b_tot(*,1),b_tot(*,2),$
btot,th,ph

ind = where(bmag_tot eq -32768,cnt)


if cnt gt 0 then begin
  pos_tot(ind,*) = 2e30
  bmag_tot(ind,*) = 2e30
  b_tot(ind,*) = 2e30
  lamda(ind,*)= 2e30
  phi(ind,*)= 2e30
  th(ind,*)= 2e30
  ph(ind,*)= 2e30
endif

store_data,'ge_pos',data={ytitle:'ge_pos',x:t_tot,y:pos_tot , max_value:1e30}
store_data,'ge_B',data={ytitle:'ge_B',x:t_tot,y:b_tot , max_value:1e30}
store_data,'ge_B_mag',data={ytitle:'ge_B_mag',x:t_tot,y:bmag_tot , max_value:1e30}
store_data,'ge_B_th' ,data={ytitle:'ge_B_th',x:t_tot,y:th,yrange:[-90.,90.], max_value:1e30}
store_data,'ge_B_ph' ,data={ytitle:'ge_B_ph',x:t_tot,y:ph,yrange:[-180.,180.], max_value:1e30}

store_data,'ge_B_lamda' ,data={ytitle:'ge_B_lamda',x:t_tot,y:lamda,yrange:[-90.,90.], max_value:1e30}
store_data,'ge_B_phi' ,data={ytitle:'ge_B_phi',x:t_tot,y:phi,yrange:[-180.,180.], max_value:1e30}

end


