
;+
;PROCEDURE:	get_i8_pla
;PURPOSE:
;	Gets key parameter data from the IMP-8 plasma experiment.
;	Gets , such as Sc_pos_i8_pla, Np, Vgse_i8, Vth
;	
;INPUT:	
;	none but will call "timespan" and ask for input if
;	time range not already set
;KEYWORDS:
;	none
;
;CREATED BY:	Tai Phan and mods by J.McFadden (modified from Davin Larson's get_swe)
;LAST MODIFICATION:	@(#)get_mfi.pro	1.8 95/09/07
;-


pro get_i8_pla       
@wind_com.pro
init_wind_lib
fname = data_directory+'i8_k0_pla_files'
get_file_names,filenames,TIME_RANGE=range,MASTERFILE=fname
ndays = n_elements(filenames)



if ndays eq 0 then begin
   print,"No IMP-8 Plasma data available from ",time_to_str(range(0)), ' to  ',time_to_str(range(1))
   return
endif

for d=0,ndays-1 do begin
   print,'Loading file: ',filenames(d),'...'
   loadcdf,filenames(d),'Time_PB5',pb5  &   t = pb5_to_time(pb5)

   loadcdf,filenames(d),'SC_pos_gse',sc_pos
   loadcdf,filenames(d),'V_GSE'      , vgse
   loadcdf,filenames(d),'THERMAL_SPEED'      , vth
   loadcdf,filenames(d),'Np'      ,np
   loadcdf,filenames(d),'GAP_FLAG'      ,gap

   if d eq 0 then begin
        t_tot  = t
        Np_tot = Np
        vth_tot = vth
        vgse_tot = vgse
	sc_pos_tot= sc_pos/6380. ; convert to RE
	gap_tot = gap
   endif else begin
        t_tot  = [t_tot,t]
        Np_tot = [Np_tot,Np]
        vth_tot = [vth_tot,vth]
        vgse_tot = [vgse_tot,vgse]
	sc_pos_tot= [sc_pos_tot,sc_pos/6380.]
	gap_tot = [gap_tot,gap]
   endelse
endfor

ind = where(gap_tot,count)  
if count ne 0 then begin
	Np_tot(ind) = !values.f_nan
	vth_tot(ind) = !values.f_nan
	vgse_tot(ind,*) = !values.f_nan
	sc_pos_tot(ind,*) = !values.f_nan
endif
print,'# pts with Gap_Flag thrown out = ',count

ind = where(Np_tot gt 5000,count)  
if count ne 0 then begin
	Np_tot(ind) = !values.f_nan
	vth_tot(ind) = !values.f_nan
	vgse_tot(ind,*) = !values.f_nan
	sc_pos_tot(ind,*) = !values.f_nan
endif
print,'# pts with Np>5000 thrown out = ',count

ind = where(vgse_tot(*,0) gt 5000,count)  
if count ne 0 then begin
	Np_tot(ind) = !values.f_nan
	vth_tot(ind) = !values.f_nan
	vgse_tot(ind,*) = !values.f_nan
	sc_pos_tot(ind,*) = !values.f_nan
endif
print,'# pts with Vp>5000 thrown out = ',count


;ind = where(np_tot eq 9999)  &  np_tot(ind) = 2e30
;ind = where(vth_tot eq 9999)  &  vth_tot(ind) = 2e30
;ind = where(vgse_tot eq 9999)  &  vgse_tot(ind) = 2e30

Tp = .00522 * vth_tot * vth_tot

store_data,'i8_pos',data={ytitle:'i8_pos',x:t_tot,y:sc_pos_tot}
store_data,'i8_pla_Np',data={ytitle:'i8_pla_Np',x:t_tot,y:Np_tot}
store_data,'i8_pla_Vp',data={ytitle:'i8_pla_Vp',x:t_tot,y:vgse_tot}
store_data,'i8_pla_Tp',data={ytitle:'i8_pla_Tp',x:t_tot,y:Tp}
store_data,'i8_pla_Vpth',data={ytitle:'i8_pla_Vpth',x:t_tot,y:vth_tot}

end


