;+
;PROCEDURE:	get_wav
;PURPOSE:	
;  Loads WAV key parameter data.
;
;INPUTS:	none, but will call "timespan" if time
;		range is not already set.
;KEYWORDS:	MOON:  Set to get Moon position data.
;
;CREATED BY:    Davin Larson
;FILE:  get_wav.pro
;LAST MODIFICATION: 96/08/05
;
;-
pro get_wav,TIME_RANGE=range,MOON = moon

fname = 'wi_k0_wav_files'
environvar = 'CDF_DATA_DIR'
dir = getenv(environvar)
if not keyword_set(dir) then $
   message,'Environment variable '+environvar+' is not defined!' 

get_file_names,filenames,TIME_RANGE=range,MASTERFILE=fname,ROOT=dir
ndays = n_elements(filenames)

if ndays eq 0 then begin
   print,"No WAV data available from ",time_to_str(range(0)), ' to ', $
   time_to_str(range(1))
   return
endif

for d=0,ndays-1 do begin
   print,'Loading file: ',filenames(d)
   loadcdf,filenames(d),'Time_PB5', pb5 ,/append
   loadcdf,filenames(d),'Ne', n_e,/append
   loadcdf,filenames(d),'E_Average', e_a,/append
;   loadcdf,filenames(d),'Ne_Quality', n_e_q,/append
;   loadcdf,filenames(d),'E_transient', e_t,/append
;   loadcdf,filenames(d),'Sol_min', sol_min,/append
;   loadcdf,filenames(d),'Sol_max', sol_max,/append
   loadcdf,filenames(d),'Moon_pos', moon_pos,/append
;   loadcdf,filenames(d),'E_Quality', e_q,/append
;   loadcdf,filenames(d),'E_Backg', e_bkg,/append
;   loadcdf,filenames(d),'GAP_FLAG', gap_flag,/append
   loadcdf,filenames(d),'E_freq_val', e_f
;   loadcdf,filenames(d),'freq_minus', e_fm
;   loadcdf,filenames(d),'freq_plus', e_fp
endfor
t = pb5_to_time(pb5)

bad = where(n_e lt 0,count)
if count ne 0 then n_e(bad) = !values.f_nan
store_data,'wi_wav_Ne',data={x:t,y:n_e}

;store_data,'wi_wav_Ne_q',data={x:t,y:n_e_q}

bad = where(e_a lt 0,count)
if count ne 0 then e_a(bad) = !values.f_nan
store_data,'wi_wav',data={x:t,y:e_a,v:e_f,spec:1,ylog:1,ystyle:1}
if keyword_set(moon) then store_data,'Moon_pos',data={x:t,y:moon_pos}


end

