;+
;PROCEDURE:	smoothspikes, data
;PURPOSE:	To smooth out annoying time spikes from bad data
;INPUT:		data array of times
;KEYWORDS:	none yet
;
;SEE ALSO:	"smooth_data_spikes"
;
;CREATED BY:	Jasper Halekas
;LAST MODIFICATION:	@(#)smoothspikes.pro	1.16 95/10/06
;
;NOTE:	This is now done automatically in "get_spec"
;-
pro smoothspikes, data

s = dimen1(data)

space = (shift(data,-1) - data)

space = space(0:(s-2))		;get rid of huge value @ end	

aspace = abs(space)

avgspace = total(aspace)/(s-1)

trouble = where(aspace gt 4*avgspace)
if trouble(0) eq -1 then return
tspots = dimen1(trouble)
if tspots eq 0 then return

up = where(space(trouble) gt 0, upn)
down = where(space(trouble) lt 0, downn)

if downn eq 0 then begin	;no spikes, only data gaps
	return
endif


realtrouble = intarr(1)
for i = 0,tspots-2 do begin
	place = trouble(i)
	placeplus = trouble(i + 1)
	delta = trouble(i + 1) - trouble(i) + 1
	deltat = delta * avgspace
	if ((delta lt 20) and ((space(place)+space(placeplus)) lt 1.5*deltat))$
	then begin
		if (dimen1(realtrouble) eq 1) then begin
			realtrouble=place
			realtrouble=[realtrouble,placeplus]
		endif else realtrouble = [realtrouble, place,placeplus]
	end
end

trouble = realtrouble
tspots = dimen1(trouble)
		 		 
tnum = tspots/2

for i = 0, (tnum-1) do begin	;do the actual smoothing

	below = data(trouble(2*i))
	above = data(trouble(2*i+1) + 1)

	for j = trouble(2*i)+1, trouble(2*i+1) do begin
		data(j) = (above - below)/(trouble(2*i+1)-trouble(2*i)) $
		* (j - (trouble(2*i))) + below
	endfor
endfor
	



return 
end	
